//////////////////////////////////////////////////////////////////////
//
// Module    : ProjectHCSettingsWrapper.cpp
// Author    : Krasimir Angelov <kr.angelov@gmail.com>
// Copyright : (c) Krasimir Angelov, All Rights Reserved
//
// implementation of the CProjectHCSettingsWrapper class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "Resource.h"
#include "ProjectHCSettingsWrapper.h"

OBJECT_ENTRY_AUTO(CLSID_HCPropertyPage, CHCPropertyPage)

// =========================================================================
//                                                 construct, init, destruct
/* static */
HRESULT CProjectHCSettingsWrapper::CreateInstance(CHCPropertyPage *pPage, IUnknown *pUnkParent, IUnknown **pIUnkPropPage)
{
	HRESULT hr = S_OK;
	CComObject<CProjectHCSettingsWrapper> * pObj;
	hr = CComObject<CProjectHCSettingsWrapper>::CreateInstance(&pObj);
    if (FAILED(hr))
		return hr;
	if (!pObj)
		return E_UNEXPECTED;

    return pObj->Init(pPage, pUnkParent, pIUnkPropPage);
}


CProjectHCSettingsWrapper::CProjectHCSettingsWrapper()
{
	m_srpIProjectHCSettings = NULL;

	m_cbstrGHCOptions = "";
	m_cbstrHugsOptions = "";
	m_cbstrNHCOptions = "";
	m_cbstrExtensions = "";

	m_pPage = NULL;
}


HRESULT CProjectHCSettingsWrapper::Init(CHCPropertyPage *pPage, IUnknown *pUnkParent, IUnknown **pIUnkPropPage)
{
	HRESULT hr;
    if (!pUnkParent || !pIUnkPropPage)
		return E_UNEXPECTED;

	// initialize the members
    hr = pUnkParent->QueryInterface(__uuidof(IProjectHCSettings), (void**) &m_srpIProjectHCSettings);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->get_GHCOptions(&m_cbstrGHCOptions);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->get_HugsOptions(&m_cbstrHugsOptions);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->get_NHCOptions(&m_cbstrNHCOptions);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->get_Extensions(&m_cbstrExtensions);
    if (FAILED(hr))
		return hr;

	m_pPage = pPage;

	*pIUnkPropPage = NULL;
    return QueryInterface(IID_IUnknown, (void**) pIUnkPropPage);
}


CProjectHCSettingsWrapper::~CProjectHCSettingsWrapper()
{
}
//                                                 construct, init, destruct
// =========================================================================


// =========================================================================
//                                                      IPerPropertyBrowsing
// Used to populate Debug Start Mode list box

STDMETHODIMP CProjectHCSettingsWrapper::GetDisplayString(
    /* [in] */ DISPID dispID,
    /* [out] */ BSTR *pBstr)
{
	if(pBstr == NULL )
		return E_POINTER;
	*pBstr = NULL;

    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::MapPropertyToPage(
    /* [in]  */ DISPID dispID,
    /* [out] */ CLSID *pClsid)
{
    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::GetPredefinedStrings(
    /* [in]  */ DISPID          dispID,
    /* [out] */ CALPOLESTR *    pCaStringsOut,
    /* [out] */ CADWORD *       pCaCookiesOut)
{
	return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::GetPredefinedValue(
    /* [in]  */ DISPID dispID,
    /* [in]  */ DWORD dwCookie,
    /* [out] */ VARIANT *pVarOut)
{
    return E_NOTIMPL;
}
//                                                      IPerPropertyBrowsing
// =========================================================================


// =========================================================================
//                                                    IVsPerPropertyBrowsing

STDMETHODIMP CProjectHCSettingsWrapper::HideProperty(DISPID dispid, BOOL* pfHide)
{
    if (!pfHide)
        return E_INVALIDARG;
    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::DisplayChildProperties(DISPID dispid, BOOL* pfDisplay)
{
    if (!pfDisplay)
        return E_INVALIDARG;
    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::GetLocalizedPropertyInfo(
    DISPID dispid,
    LCID localeID,
    BSTR* pbstrLocalizedName,
    BSTR* pbstrLocalizedDescription)
{
    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::HasDefaultValue(DISPID dispid, BOOL* fDefault)
{
    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::IsPropertyReadOnly(DISPID dispid, BOOL* pfReadOnly)
{
    if (!pfReadOnly)
        return E_INVALIDARG;
    return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::GetClassName(BSTR*)
{
	return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::CanResetPropertyValue(DISPID , BOOL* )
{
	return E_NOTIMPL;
}


STDMETHODIMP CProjectHCSettingsWrapper::ResetPropertyValue(DISPID )
{
	return E_NOTIMPL;
}
//                                                    IVsPerPropertyBrowsing
// =========================================================================

STDMETHODIMP CProjectHCSettingsWrapper::get_GHCOptions(BSTR *pValue)
{
	return m_cbstrGHCOptions.CopyTo(pValue);
}

STDMETHODIMP CProjectHCSettingsWrapper::put_GHCOptions(BSTR Value)
{
	HRESULT hr = m_cbstrGHCOptions.AssignBSTR(Value);
	if (FAILED(hr))
		return hr;

	m_pPage->SetDirty(TRUE);
	return S_OK;
}

STDMETHODIMP CProjectHCSettingsWrapper::get_HugsOptions(BSTR *pValue)
{
	return m_cbstrHugsOptions.CopyTo(pValue);
}

STDMETHODIMP CProjectHCSettingsWrapper::put_HugsOptions(BSTR Value)
{
	HRESULT hr = m_cbstrHugsOptions.AssignBSTR(Value);
	if (FAILED(hr))
		return hr;

	m_pPage->SetDirty(TRUE);
	return S_OK;
}

STDMETHODIMP CProjectHCSettingsWrapper::get_NHCOptions(BSTR *pValue)
{
	return m_cbstrNHCOptions.CopyTo(pValue);
}

STDMETHODIMP CProjectHCSettingsWrapper::put_NHCOptions(BSTR Value)
{
	HRESULT hr = m_cbstrNHCOptions.AssignBSTR(Value);
	if (FAILED(hr))
		return hr;

	m_pPage->SetDirty(TRUE);
	return S_OK;
}

STDMETHODIMP CProjectHCSettingsWrapper::get_Extensions(BSTR *pValue)
{
	return m_cbstrExtensions.CopyTo(pValue);
}

STDMETHODIMP CProjectHCSettingsWrapper::put_Extensions(BSTR Value)
{
	HRESULT hr = m_cbstrExtensions.AssignBSTR(Value);
	if (FAILED(hr))
		return hr;

	m_pPage->SetDirty(TRUE);
	return S_OK;
}

STDMETHODIMP CProjectHCSettingsWrapper::Commit()
{
	HRESULT hr;

	hr = m_srpIProjectHCSettings->put_GHCOptions(m_cbstrGHCOptions);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->put_HugsOptions(m_cbstrHugsOptions);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->put_NHCOptions(m_cbstrNHCOptions);
    if (FAILED(hr))
		return hr;

    hr = m_srpIProjectHCSettings->put_Extensions(m_cbstrExtensions);
    if (FAILED(hr))
		return hr;

	return S_OK;
}
